# VSCode for Development

[vscode](https://code.visualstudio.com) is recommended for open-source development. When you open the project in vscode, [settings](./settings.json) and [recommended extentions](./extensions.json) should be loaded automatically.